---
name: Bug Report
about: Report a bug to help us improve
title: ''
labels: ''
assignees: ''

---

## Description

Please provide a description of the problem.

## Expected Behaviour

Please describe what you expected would happen.

## Actual Behaviour

Please describe what happened instead.

## Terraform Code

If relevant, terraform code sample, either unparseable input or incorrect output.

## Affected Version

Please provide the version number where this issue was encountered.

## Steps to Reproduce

1. First step
1. Second step
1. etc.

## Checklist

<!-- TODO: Update the link below to point to your project's contributing guidelines -->
- [ ] I have read the [contributing guidelines](https://github.com/wayfair-incubator/oss-template/blob/main/CONTRIBUTING.md)
- [ ] I have verified this does not duplicate an existing issue
